@@ -9,6 +9,8 @@ from typing import Dict, Union, List
 import orjson
 import toml
 from loguru import logger
+
+from pbt.config import PBTConfig
 from pbt.poetry import Poetry
 
 
@@ -38,7 +40,8 @@ class Package:
 
         if rebuild:
             logger.info("Build package {}", self.name)
-            shutil.rmtree(str(self.dir / "dist"))
+            if (self.dir / "dist").exists():
+                shutil.rmtree(str(self.dir / "dist"))
             subprocess.check_call(["poetry", "build"], cwd=str(self.dir))
 
     def is_modified(self) -> bool:
@@ -110,12 +113,15 @@ class Package:
             ]
         return packages
 
+    def __repr__(self) -> str:
+        return f"{self.name}={self.version}"
 
-def search_packages(root_dir: Path):
+
+def search_packages(pbt_cfg: PBTConfig):
     logger.info("Search packages...")
     packages = {}
 
-    for poetry_file in glob(str(root_dir / "*/pyproject.toml")):
+    for poetry_file in glob(str(pbt_cfg.cwd / "*/pyproject.toml")):
         poetry_file = Path(poetry_file)
         package_dir = poetry_file.parent
 
